==> pulumi-aws-kotlin-6.13.1.0-sources.jar: com/pulumi/aws/medialive/kotlin/inputs/ChannelEncoderSettingsAudioDescriptionAudioWatermarkSettingsArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.aws.medialive.kotlin.inputs

import com.pulumi.aws.medialive.inputs.ChannelEncoderSettingsAudioDescriptionAudioWatermarkSettingsArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.Suppress
import kotlin.Unit
import kotlin.jvm.JvmName

/**
 *
 * @property nielsenWatermarksSettings
 */
public data class ChannelEncoderSettingsAudioDescriptionAudioWatermarkSettingsArgs(
    public val nielsenWatermarksSettings:
    Output<ChannelEncoderSettingsAudioDescriptionAudioWatermarkSettingsNielsenWatermarksSettingsArgs>? =
        null,
) :
    ConvertibleToJava<com.pulumi.aws.medialive.inputs.ChannelEncoderSettingsAudioDescriptionAudioWatermarkSettingsArgs> {
    override fun toJava():
        com.pulumi.aws.medialive.inputs.ChannelEncoderSettingsAudioDescriptionAudioWatermarkSettingsArgs =
        com.pulumi.aws.medialive.inputs.ChannelEncoderSettingsAudioDescriptionAudioWatermarkSettingsArgs.builder()
            .nielsenWatermarksSettings(
                nielsenWatermarksSettings?.applyValue({ args0 ->
                    args0.let({ args0 ->
                        args0.toJava()
                    })
                }),
            ).build()
}

/**
 * Builder for [ChannelEncoderSettingsAudioDescriptionAudioWatermarkSettingsArgs].
 */
@PulumiTagMarker
public class ChannelEncoderSettingsAudioDescriptionAudioWatermarkSettingsArgsBuilder internal
constructor() {
    private var nielsenWatermarksSettings:
        Output<ChannelEncoderSettingsAudioDescriptionAudioWatermarkSettingsNielsenWatermarksSettingsArgs>? =
        null

    /**
     * @param value
     */
    @JvmName("eyhyaammjkswjkjv")
    public suspend
    fun nielsenWatermarksSettings(`value`: Output<ChannelEncoderSettingsAudioDescriptionAudioWatermarkSettingsNielsenWatermarksSettingsArgs>) {
        this.nielsenWatermarksSettings = value
    }

    /**
     * @param value
     */
    @JvmName("sywwsodnhvwkifeg")
    public suspend
    fun nielsenWatermarksSettings(`value`: ChannelEncoderSettingsAudioDescriptionAudioWatermarkSettingsNielsenWatermarksSettingsArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.nielsenWatermarksSettings = mapped
    }

    /**
     * @param argument
     */
    @JvmName("coadooxepijjkcvl")
    public suspend
    fun nielsenWatermarksSettings(argument: suspend ChannelEncoderSettingsAudioDescriptionAudioWatermarkSettingsNielsenWatermarksSettingsArgsBuilder.() -> Unit) {
        val toBeMapped =
            ChannelEncoderSettingsAudioDescriptionAudioWatermarkSettingsNielsenWatermarksSettingsArgsBuilder().applySuspend {
                argument()
            }.build()
        val mapped = of(toBeMapped)
        this.nielsenWatermarksSettings = mapped
    }

    internal fun build(): ChannelEncoderSettingsAudioDescriptionAudioWatermarkSettingsArgs =
        ChannelEncoderSettingsAudioDescriptionAudioWatermarkSettingsArgs(
            nielsenWatermarksSettings = nielsenWatermarksSettings,
        )
}

==> pulumi-aws-kotlin-6.49.1.0-sources.jar: com/pulumi/aws/medialive/kotlin/inputs/ChannelEncoderSettingsAudioDescriptionAudioWatermarkSettingsArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.aws.medialive.kotlin.inputs

import com.pulumi.aws.medialive.inputs.ChannelEncoderSettingsAudioDescriptionAudioWatermarkSettingsArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.Suppress
import kotlin.Unit
import kotlin.jvm.JvmName

/**
 *
 * @property nielsenWatermarksSettings
 */
public data class ChannelEncoderSettingsAudioDescriptionAudioWatermarkSettingsArgs(
    public val nielsenWatermarksSettings: Output<ChannelEncoderSettingsAudioDescriptionAudioWatermarkSettingsNielsenWatermarksSettingsArgs>? =
        null,
) :
    ConvertibleToJava<com.pulumi.aws.medialive.inputs.ChannelEncoderSettingsAudioDescriptionAudioWatermarkSettingsArgs> {
    override fun toJava(): com.pulumi.aws.medialive.inputs.ChannelEncoderSettingsAudioDescriptionAudioWatermarkSettingsArgs =
        com.pulumi.aws.medialive.inputs.ChannelEncoderSettingsAudioDescriptionAudioWatermarkSettingsArgs.builder()
            .nielsenWatermarksSettings(
                nielsenWatermarksSettings?.applyValue({ args0 ->
                    args0.let({ args0 ->
                        args0.toJava()
                    })
                }),
            ).build()
}

/**
 * Builder for [ChannelEncoderSettingsAudioDescriptionAudioWatermarkSettingsArgs].
 */
@PulumiTagMarker
public class ChannelEncoderSettingsAudioDescriptionAudioWatermarkSettingsArgsBuilder internal constructor() {
    private var nielsenWatermarksSettings:
        Output<ChannelEncoderSettingsAudioDescriptionAudioWatermarkSettingsNielsenWatermarksSettingsArgs>? =
        null

    /**
     * @param value
     */
    @JvmName("gjkdcxktijvglilp")
    public suspend fun nielsenWatermarksSettings(`value`: Output<ChannelEncoderSettingsAudioDescriptionAudioWatermarkSettingsNielsenWatermarksSettingsArgs>) {
        this.nielsenWatermarksSettings = value
    }

    /**
     * @param value
     */
    @JvmName("qgssdkixeqrhfdyi")
    public suspend fun nielsenWatermarksSettings(`value`: ChannelEncoderSettingsAudioDescriptionAudioWatermarkSettingsNielsenWatermarksSettingsArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.nielsenWatermarksSettings = mapped
    }

    /**
     * @param argument
     */
    @JvmName("jtrthgfiuyagrgpp")
    public suspend fun nielsenWatermarksSettings(argument: suspend ChannelEncoderSettingsAudioDescriptionAudioWatermarkSettingsNielsenWatermarksSettingsArgsBuilder.() -> Unit) {
        val toBeMapped =
            ChannelEncoderSettingsAudioDescriptionAudioWatermarkSettingsNielsenWatermarksSettingsArgsBuilder().applySuspend {
                argument()
            }.build()
        val mapped = of(toBeMapped)
        this.nielsenWatermarksSettings = mapped
    }

    internal fun build(): ChannelEncoderSettingsAudioDescriptionAudioWatermarkSettingsArgs =
        ChannelEncoderSettingsAudioDescriptionAudioWatermarkSettingsArgs(
            nielsenWatermarksSettings = nielsenWatermarksSettings,
        )
}
